![Galamo Logo](images/galamo_main.svg)


----
![PyPI Status](https://img.shields.io/pypi/v/galamo.svg)
[![Documentation](https://img.shields.io/badge/documentation-latest-green.svg)](https://www.galamo.org/learn)
----

**Galamo** is a Python package designed for astronomical modeling and analysis, offering tools for AGN research, galaxy classification, and more.

- [Website](https://www.galamo.org)
- [Documentation](https://docs.galamo.org/)
- [Discussion Forum](https://community.galamo.org/)
- [Mailing List](https://mail.python.org/mailman/listinfo/galamo)

## Installation

To install `galamo` from PyPI, use:

```bash
pip install galamo --upgrade
```

For detailed instructions, see the [installation guide](https:/www.galamo.org/install).

## Contributing

We welcome contributions from the community! Please follow our [Code of Conduct](https://www.galamo.org/code_of_conduct.html) and check out the [contribution guide](https://www.galamo.org/contribute.html) for more details.

## Acknowledging and Citing

See the [citation guide](https://www.galamo.org/acknowledging.html) and the [CITATION](https://github.com/galamo-org/galamo/blob/main/CITATION) file.

## Supporting the Project

![DAC](https://img.shields.io/badge/powered%20by-DAC-orange.svg?style=flat&colorA=E1523D&colorB=007D8A)
![Donate](https://img.shields.io/badge/Donate-to%20Galamo-brightgreen.svg)

Galamo needs support. Consider donating to support our mission!

## License

Galamo is licensed under a BSD 3-Clause License - see the [LICENSE](LICENSE) file for details.
